==> ms-users-12.1.1.tgz: package/lib/utils/organization/send-invite-email.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const Promise = require('bluebird');

const generateEmail = require('../challenges/email/generate.js');

const {
  ORGANIZATIONS_INVITATIONS_INDEX,
  TOKEN_METADATA_FIELD_CONTEXT,
  TOKEN_METADATA_FIELD_SENDED_AT
} = require('../../constants.js');

module.exports = function sendInviteMail(params) {
  const {
    redis,
    tokenManager
  } = this;
  const {
    email,
    action,
    ctx = {}
  } = params;
  const now = Date.now();
  return tokenManager.create({
    id: email,
    action,
    regenerate: true,
    metadata: {
      [TOKEN_METADATA_FIELD_CONTEXT]: ctx,
      [TOKEN_METADATA_FIELD_SENDED_AT]: now
    }
  }).then(token => Promise.bind(this, [email, action, _objectSpread({}, ctx, {
    token
  }), {
    send: true
  }]).spread(generateEmail).tap(() => redis.sadd(ORGANIZATIONS_INVITATIONS_INDEX, email)));
};

==> ms-users-14.5.1.tgz: package/lib/utils/organization/send-invite-email.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const generateEmail = require('../challenges/email/generate.js');

const {
  organizationInvite,
  inviteId,
  TOKEN_METADATA_FIELD_CONTEXT,
  TOKEN_METADATA_FIELD_SENDED_AT,
  USERS_ACTION_ORGANIZATION_INVITE,
  TOKEN_METADATA_FIELD_METADATA
} = require('../../constants.js');

module.exports = async function sendInviteMail(params) {
  const {
    redis,
    tokenManager
  } = this;
  const {
    email,
    ctx
  } = params;
  const now = Date.now();
  const token = await tokenManager.create({
    id: inviteId(ctx.organizationId, email),
    action: USERS_ACTION_ORGANIZATION_INVITE,
    regenerate: true,
    metadata: {
      [TOKEN_METADATA_FIELD_METADATA]: {
        permissions: ctx.permissions
      },
      [TOKEN_METADATA_FIELD_CONTEXT]: ctx,
      [TOKEN_METADATA_FIELD_SENDED_AT]: now
    }
  });
  await generateEmail.call(this, email, USERS_ACTION_ORGANIZATION_INVITE, _objectSpread(_objectSpread({}, ctx), {}, {
    token
  }), {
    send: true
  });
  await redis.sadd(organizationInvite(ctx.organizationId), email);
};
